@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-03-31 16:33:47 mtw>
+# Last changed Time-stamp: <2014-12-01 23:30:45 mtw>
 #
 # ***********************************************************************
 # *  Copyright notice
@@ -30,7 +30,7 @@ use Getopt::Long qw( :config posix_default bundling no_ignore_case );
 use Pod::Usage;
 use Data::Dumper;
 use IPC::Cmd qw(can_run);
-use Bio::ViennaNGS::Util  qw(bed2bigBed);
+use Bio::ViennaNGS  qw(bed2bigBed);
 use Bio::ViennaNGS::SpliceJunc qw(bed6_ss_to_bed12);
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
@@ -102,15 +102,16 @@ sj_visualizer.pl - Produce BED12 from BED6 splice junction files.
 
 =head1 SYNOPSIS
 
-sj_visualizer.pl [-s I<FILE>] [options]
+sj_visualizer.pl [-s I<FILE>] [-f I<FILE>]
+[options]
 
 =head1 DESCRIPTION
 
 Convert splice junctions from mapped RNA-seq data to BED12 format for
-easy genome browser visualization. The program expects BED6 input in
-segemehl splice junction format (see the L<segemehl
+easy visualization in genome browsers. The program expects BED6 input
+in segemehl splice junction format (see the L<segemehl
 documentation|http://www.bioinf.uni-leipzig.de/Software/segemehl/segemehl_manual_0_1_7.pdf>
-for details) and produces BED12 and optionally bigBed output.
+for details).
 
 =head1 OPTIONS
 
@@ -145,6 +146,7 @@ Filter circular splice junctions
 
 Relative output path
 
+
 =item B<--help -h>
 
 Print short help
